@@ -716,7 +716,7 @@ QList<QString> DatabaseManager::getGroups()
 {
 	QList<QString> result;
 
-	QSqlQuery query("select distinct groupName from targets order by groupName");
+	QSqlQuery query("select distinct coalesce(groupName,'') from targets order by groupName");
 	while (query.next()) {
 		result.append(query.value(0).toString());
 	}
