@@ -325,6 +325,8 @@ void DetailWindow::_addField (TargetField * field) {
 		QTextEdit * nameLineEdit = new QTextEdit(this);
 		//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
+		//nameLineEdit->setCompleter(NULL);
+
 		nameLineEdit->setText (field->value);
 		this->values.append (nameLineEdit);
 		//nameLineEdit->setUserData(0,info);
@@ -341,6 +343,8 @@ void DetailWindow::_addField (TargetField * field) {
 	}*/
 	else {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
+		nameLineEdit->setCompleter(NULL);
+		//nameLineEdit->inputContext()->
 		//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
