@@ -49,7 +49,7 @@ class DetailWindow: public QMainWindow
 	Q_OBJECT
 
 public:
-	DetailWindow (Target * target, bool edit, eWallet *paTarget, QWidget *parent = 0);
+	DetailWindow (Target * target, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent = 0);
 	~DetailWindow ();
 	
 	void addField (TargetField * field);
@@ -66,6 +66,7 @@ private:
 	QScrollArea * entryScrollArea;
 
 	QLineEdit * nameLineEdit;
+	QLineEdit * groupLineEdit;
 	QComboBox * typeLineEdit;
 	QList<QLineEdit*> labels;
 	QList<QWidget*> values;
