@@ -107,6 +107,14 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	QObject::connect(aboutButton, SIGNAL(clicked()), this, SLOT(about()));
 	dlgBtnBox->addButton(aboutButton, QDialogButtonBox::ActionRole);
 
+	QPushButton * donateButton = new QPushButton(QIcon(":/resources/donate.png"), "Donate", this);
+	donateButton->setFixedHeight(70);
+	donateButton->setContextMenuPolicy(Qt::NoContextMenu);
+	donateButton->setFocusPolicy(Qt::NoFocus);
+	donateButton->setIconSize(QSize(48, 48));
+	QObject::connect(donateButton, SIGNAL(clicked()), this, SLOT(donate()));
+	dlgBtnBox->addButton(donateButton, QDialogButtonBox::ActionRole);
+
 //	QPushButton * deleteButton = new QPushButton(QIcon(":/resources/delete.png"), "Delete DB", this);
 //	deleteButton->setFixedHeight(70);
 //	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
@@ -152,6 +160,10 @@ void LoginDialog::about()
 {
     QMessageBox::about(this, "About qtWallet", TEXT_ABOUT);
 }
+void LoginDialog::donate() {
+	QDesktopServices::openUrl( QUrl::fromEncoded("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted" ) );
+}
+
 void LoginDialog::clearS()
 {
 	label->selectAll();
