@@ -523,7 +523,7 @@ void eWallet::showGroups(bool reset)
 
 	fnListWidget->setCurrentRow(0);
 
-	//update();
+	update();
 }
 
 void eWallet::showInfo(bool reset) {
@@ -580,7 +580,7 @@ void eWallet::showTargets(bool reset, const QString & filter)
 
 	fnListWidget->setCurrentRow(0);
 
-	//update();
+	update();
 }
 
 void eWallet::createMenu()
@@ -602,7 +602,7 @@ void eWallet::createMenu()
 		menuBar()->addAction("Invert Sort", this, SLOT(sort()));
 		menuBar()->addAction("Import", this, SLOT(import()));
 		menuBar()->addAction("Export", this, SLOT(exportData()));
-		menuBar()->addAction("Change Mode", this, SLOT(changeMode()));
+		menuBar()->addAction("Change View", this, SLOT(changeMode()));
 		menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
 	}
 }
